@@ -24,8 +24,6 @@ raw data specified in version discovery responses.
 import logging
 import re
 
-from positional import positional
-
 from keystoneclient import exceptions
 from keystoneclient.i18n import _
 
@@ -33,7 +31,6 @@ from keystoneclient.i18n import _
 _LOGGER = logging.getLogger(__name__)
 
 
-@positional()
 def get_version_data(session, url, authenticated=None):
     """Retrieve raw version data from a url."""
     headers = {'Accept': 'application/json'}
@@ -141,7 +138,6 @@ class Discover(object):
     DEPRECATED_STATUSES = ('deprecated',)
     EXPERIMENTAL_STATUSES = ('experimental',)
 
-    @positional()
     def __init__(self, session, url, authenticated=None):
         self._data = get_version_data(session, url,
                                       authenticated=authenticated)
